jacinle.logging
===============

.. automodule:: jacinle.logging

   
   
   .. rubric:: Module attributes

   .. autosummary::
   
      logger
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      JacLogFormatter
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      get_logger
      set_default_level
      set_logger_default_level
      set_logger_output_file
      set_output_file
   
   

   
   
   








.. rubric:: Class JacLogFormatter
.. autoclass:: JacLogFormatter
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: get_logger

.. autofunction:: set_default_level

.. autofunction:: set_logger_default_level

.. autofunction:: set_logger_output_file

.. autofunction:: set_output_file


